@@ -190,7 +190,7 @@ def join_ksegments(kpath,kseg_inds=[]):
             path_list[ind:] -= path_list[ind] - path_list[ind-1]
     return list(path_list)
 
-def get_kpts(xml_data, skipk = 0,kseg_inds=[]):
+def get_kpts(xml_data, skipk = 0):
     for kpts in xml_data.root.iter('varray'):
         if(kpts.attrib=={'name': 'kpointlist'}):
             kpoints=[[float(item) for item in arr.text.split()] for arr in kpts.iter('v')]
@@ -198,8 +198,7 @@ def get_kpts(xml_data, skipk = 0,kseg_inds=[]):
     #KPath solved.
     kpath = get_space_info(xml_data).cartesian_kpath[skipk:]
     kpath = kpath - kpath[0] # Shift to start at 0
-    # If broken path, then join points.
-    kpath = join_ksegments(kpath,kseg_inds)
+    # Do Not Join KPath if it is broken, leave that to plotting functions
     return serializer.Dict2Data({'NKPTS':len(kpoints),'kpoints':kpoints,'kpath':kpath})
 
 def get_tdos(xml_data,spin_set=1,elim=[]):
@@ -240,44 +239,51 @@ def get_tdos(xml_data,spin_set=1,elim=[]):
         dos_dic= {'E_Fermi':efermi,'ISPIN':ISPIN,'grid_range':range(lo_ind,up_ind),'tdos':tdos}
     return serializer.Dict2Data(dos_dic)
 
-def get_evals(xml_data,skipk=None,elim=[]):
-    evals=[]; #assign for safely exit if wrong spin set entered.
-    ISPIN=get_ispin(xml_data=xml_data)
-    if skipk!=None:
+def get_evals(xml_data, skipk = None, elim = []):
+    evals, occs = [], [] #assign for safely exit if wrong spin set entered.
+    ISPIN = get_ispin(xml_data=xml_data)
+    if skipk != None:
         skipk=skipk
     else:
-        skipk=exclude_kpts(xml_data=xml_data) #that much to skip by default
+        skipk = exclude_kpts(xml_data=xml_data) #that much to skip by default
     for neighbor in xml_data.root.iter('eigenvalues'):
         for item in neighbor[0].iter('set'):
             if(ISPIN==1):
                 if(item.attrib=={'comment': 'spin 1'}):
-                    evals=np.array([[float(th.text.split()[0]) for th in thing] for thing in item])[skipk:]
-                    NBANDS=len(evals[0])
+                    evals = np.array([[[float(t) for t in th.text.split()] for th in thing] for thing in item])[skipk:]
+                    evals, occs = evals[:,:,0], evals[:,:,1]
+                    NBANDS = len(evals[0])
             if(ISPIN==2):
                 if(item.attrib=={'comment': 'spin 1'}):
-                    eval_1=np.array([[float(th.text.split()[0]) for th in thing] for thing in item])[skipk:]
+                    eval_1 = np.array([[[float(t) for t in th.text.split()] for th in thing] for thing in item])[skipk:]
+                    eval_1, occs_1 = eval_1[:,:,0], eval_1[:,:,1]
                 if(item.attrib=={'comment': 'spin 2'}):
-                    eval_2=np.array([[float(th.text.split()[0]) for th in thing] for thing in item])[skipk:]
-                    evals={'SpinUp':eval_1,'SpinDown':eval_2}
+                    eval_2=np.array([[[float(t) for t in th.text.split()] for th in thing] for thing in item])[skipk:]
+                    eval_2, occs_2 = eval_2[:,:,0], eval_2[:,:,1]
+                    evals = {'SpinUp':eval_1,'SpinDown':eval_2}
+                    occs = {'SpinUp':occs_1,'SpinDown':occs_2}
                     NBANDS=len(eval_1[0])
 
     for i in xml_data.root.iter('i'): #efermi for condition required.
         if(i.attrib=={'name': 'efermi'}):
             efermi=float(i.text)
-    evals_dic={'E_Fermi':efermi,'ISPIN':ISPIN,'NBANDS':NBANDS,'evals':evals,'indices': range(NBANDS)}
+    evals_dic={'E_Fermi':efermi,'ISPIN':ISPIN,'NBANDS':NBANDS,'evals':evals,'indices': range(NBANDS),'occs':occs}
     if elim: #check if elim not empty
         if(ISPIN==1):
             up_ind=np.max(np.where(evals[:,:]-efermi<=np.max(elim))[1])+1
             lo_ind=np.min(np.where(evals[:,:]-efermi>=np.min(elim))[1])
-            evals=evals[:,lo_ind:up_ind]
+            evals = evals[:,lo_ind:up_ind]
+            occs = occs[:,lo_ind:up_ind]
         if(ISPIN==2):
             up_ind=np.max(np.where(eval_1[:,:]-efermi<=np.max(elim))[1])+1
             lo_ind=np.min(np.where(eval_1[:,:]-efermi>=np.min(elim))[1])
             evals={'SpinUp':eval_1[:,lo_ind:up_ind],'SpinDown':eval_2[:,lo_ind:up_ind]}
+            occs = {'SpinUp':occs_1[:,lo_ind:up_ind],'SpinDown':occs_2[:,lo_ind:up_ind]}
         NBANDS = int(up_ind - lo_ind) #update Bands
         evals_dic['NBANDS'] = NBANDS
         evals_dic['indices'] = range(lo_ind,up_ind)
         evals_dic['evals'] = evals
+        evals_dic['occs'] = occs
     return serializer.Dict2Data(evals_dic)
 
 def get_bands_pro_set(xml_data, spin_set=1, skipk=0, bands_range=None, set_path=None):
@@ -433,14 +439,13 @@ def get_structure(xml_data):
             'positions': np.array(positions),'labels':labels,'unique': unique_d}
     return serializer.PoscarData(st_dic)
 
-def export_vasprun(path = None, skipk = None, elim = [], kseg_inds = [], shift_kpath = 0, dos_only = False):
+def export_vasprun(path = None, skipk = None, elim = [], shift_kpath = 0, dos_only = False):
     """
     - Returns a full dictionary of all objects from `vasprun.xml` file. It first try to load the data exported by powershell's `Export-VR(Vasprun)`, which is very fast for large files. It is recommended to export large files in powershell first.
     - **Parameters**
         - path       : Path to `vasprun.xml` file. Default is `'./vasprun.xml'`.
         - skipk      : Default is None. Automatically detects kpoints to skip.
         - elim       : List [min,max] of energy interval. Default is [], covers all bands.
-        - kseg_inds  : List of indices of kpoints where path is broken.
         - shift_kpath: Default 0. Can be used to merge multiple calculations on single axes side by side.
     
     **Returns**: `pivotpy.serializer.VasprunData` object.
@@ -458,7 +463,7 @@ def export_vasprun(path = None, skipk = None, elim = [], kseg_inds = [], shift_k
         skipk = exclude_kpts(xml_data) #that much to skip by default
     info_dic = get_summary(xml_data) #Reads important information of system.
     #KPOINTS
-    kpts = get_kpts(xml_data,skipk=skipk,kseg_inds=kseg_inds)
+    kpts = get_kpts(xml_data,skipk=skipk)
     #EIGENVALS
     eigenvals = get_evals(xml_data,skipk=skipk,elim=elim)
     #TDOS
@@ -513,7 +518,7 @@ def _validate_evr(path_evr=None,**kwargs):
 
     if isinstance(path_evr,str):
         if os.path.isfile(path_evr):
-            # kwargs -> skipk=skipk,elim=elim,kseg_inds=kseg_inds
+            # kwargs -> skipk=skipk,elim=elim
             return export_vasprun(path=path_evr,**kwargs)
         else:
             raise FileNotFoundError(f'File {path_evr!r} not found!')
